package com.jeeplus.test.oss.controller;

import com.jeeplus.test.oss.domain.WorkAttachment;
import com.jeeplus.test.oss.service.OssService;
import com.jeeplus.test.oss.service.dto.OssServiceDto;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Slf4j
@Api(tags ="oss")
@RestController
@RequestMapping(value = "/oss/file")
public class OssFileController {

    @Value("${config.accessory.aliyun.aliyunUrl}")
    private String aliyunUrl;

    @Resource
    private OssService ossService;

    @ApiOperation(value = "保存数据")
    @PostMapping("/saveMsg")
    public void saveMsg(@RequestBody List<OssServiceDto> dtos) {
        ossService.saveMsg(dtos);
    }

    @GetMapping("/deleteMsgByFileName")
    @ApiOperation(value = "删除数据")
    public void deleteMsgByFileName(@RequestParam String url) {
        ossService.deleteMsgByFileName(url);
    }

    @GetMapping("/deleteMsgById")
    @ApiOperation(value = "根据id删除数据")
    public void deleteMsgById(@RequestParam String id) {
        ossService.deleteMsgById(id);
    }

    @GetMapping("/getTemporaryUrl")
    @ApiOperation(value = "根据url获取临时文件地址")
    public ResponseEntity<String> getTemporaryUrl(@RequestParam String url) {
        String temporaryLookUrl = ossService.getFileTemporaryLookUrl(aliyunUrl + url);
        return ResponseEntity.ok(temporaryLookUrl);
    }

    @GetMapping("/findFileList")
    @ApiOperation(value = "查询数据")
    public ResponseEntity<List<WorkAttachment>> findFileList(@RequestParam("attachmentId") String attachmentId) {
        List<WorkAttachment> list = ossService.findFileList(attachmentId);
        return ResponseEntity.ok(list);
    }
}
